@@ -110,7 +110,10 @@ class self_describing_environment(object):
                 if all_unique_id_dict[desc_id] == 1:
                     continue
                 # get the descriptors
-                desc_of_id = [x for x in scoped_descriptors if x.descriptor_contents['id'].lower() == desc_id]
+                desc_of_id = [
+                    x for x in scoped_descriptors
+                    if 'id' in x.descriptor_contents and x.descriptor_contents['id'].lower() == desc_id
+                ]
                 paths_of_desc_of_id = [x.file_path for x in desc_of_id]
                 invalid_desc_paths = f"{os.pathsep} ".join(paths_of_desc_of_id)
                 logging.error(f"Descriptors that have this id {desc_id}: {invalid_desc_paths}")
